pub enum Event<T: Config<I>, I: 'static = ()> {
Xp {
id: XpId<T>,
xp: T::Xp,
},
XpOwner {
id: XpId<T>,
owner: T::AccountId,
},
XpOfOwner {
owner: T::AccountId,
ids: Vec<XpId<T>>,
},
XpEarn {
id: XpId<T>,
xp: T::Xp,
},
XpReap {
id: XpId<T>,
},
XpSlash {
id: XpId<T>,
xp: T::Xp,
},
XpLock {
of: XpId<T>,
reason: T::LockReason,
xp: T::Xp,
},
XpLockBurn {
of: XpId<T>,
reason: T::LockReason,
},
XpLockSlash {
of: XpId<T>,
reason: T::LockReason,
xp: T::Xp,
},
XpReserve {
of: XpId<T>,
reason: T::ReserveReason,
xp: T::Xp,
},
XpReserveSlash {
of: XpId<T>,
reason: T::ReserveReason,
xp: T::Xp,
},
GenesisConfigUpdated(ForceGenesisConfig<T, I>),
// some variants omitted
}Expand description
XP Pallet Events (emitted via Pallet::deposit_event)
Variants
Xp
XP was created or mutated for a given key.
XpOwner
XP ownership was assigned or transferred to a new owner.
XpOfOwner
XpId’s associated with the owner.
XpEarn
XP was earned for the given key.
XpReap
XP entry was reaped (finalized and removed).
XpSlash
XP points were slashed from an XP entry.
XpLock
XP was locked for a specific runtime intent.
XpLockBurn
A lock was removed (burned) from an XP key.
XpLockSlash
Locked XP points were slashed from an XP key..
XpReserve
XP was reserved for a specific runtime intent.
XpReserveSlash
Reserved XP points were slashed from an XP key..
GenesisConfigUpdated(ForceGenesisConfig<T, I>)
A genesis config parameter was updated forcefully.