pub type LockedXpOf<T: Config<I>, I: 'static = ()> = StorageMap<_GeneratedPrefixForStorageLockedXpOf<T, I>, Blake2_128Concat, XpId<T>, BoundedVec<IdXp<T::LockReason, T::Xp>, VariantCountOf<T::LockReason>>, OptionQuery>;Expand description
Per-key locks (bounded by reason enum).
Maps each XP key XpId to a bounded vector of lock entries IdXp,
with the number of locks limited by the number of variants in
Config::LockReason.
Each lock entry per-key represents XP locked for a specific reason or runtime intent.
Storage type is [StorageMap] with key type XpId < T > and value type BoundedVec < IdXp < T :: LockReason, T :: Xp > , VariantCountOf < T :: LockReason > >.
Aliased Type
pub struct LockedXpOf<T: Config<I>, I: 'static = ()>(/* private fields */);