Type Alias ReapedXp

pub type ReapedXp<T: Config<I>, I: 'static = ()> = StorageMap<_GeneratedPrefixForStorageReapedXp<T, I>, Blake2_128Concat, XpId<T>, (), OptionQuery>;
Blacklist of finalized (reaped) XP keys.

Maps each reaped XP key XpId to an empty tuple, indicating that the XP entry has been finalized and cannot be recreated or reused.

Storage type is [StorageMap] with key type XpId < T > and value type ().

Aliased Type

pub struct ReapedXp<T: Config<I>, I: 'static = ()>(/* private fields */);