pub enum Call<T: Config<I>, I: 'static = ()> {
call {
xp_id: XpId<T>,
call: Box<<T as Config<I>>::RuntimeCall>,
},
handover {
xp_id: XpId<T>,
new_owner: T::AccountId,
},
dispose {
owner: T::AccountId,
xp_id: XpId<T>,
},
force_handover {
owner: T::AccountId,
xp_id: XpId<T>,
new_owner: T::AccountId,
},
force_genesis_config {
field: ForceGenesisConfig<T, I>,
},
// some variants omitted
}Expand description
XP Pallet Extrinsics includes major state mutation functions with origin authentication. Some read only functions are given for
Variants
call
Executes a runtime call using an XP identity as the origin.
Origin: Signed (must be the owner of the XP identity)
This extrinsic allows the owner of an XP identity to dispatch a call on its behalf. While an XP identity is not a native account, it can act as a logical origin for execution through owner authorization.
The caller must be the registered owner of the given xp_id.
Upon successful verification, the provided call is dispatched
with the XP identity as the signed origin.
handover
Transfer or handover ownership of an XP key to another account.
Origin: Signed user (must be the current XP key owner)
This extrinsic allows the current owner of an XP key to transfer ownership to another account. The call will fail if the destination account is already the owner or if the caller does not own the XP key.
On success, ownership of the XP key is transferred to the target account and an event is emitted.
Emits Event::XpOwner with the XP key and new owner.
dispose
Dispose (Reap) an XP key.
Origin: Signed user
This extrinsic allows any signed account to finalize and remove XP entries that are no longer valid.
For an XP key, it checks:
- The key exists in storage,
- The key is considered “dead” (does not meet minimum timestamp requirements),
- The key has no active locks.
If all checks pass, the XP entry is reaped (removed from storage and blacklisted).
Emits Event::XpReap with each successfully reaped XP key.
force_handover
Force transfer/handover ownership of an XP key to another account.
Origin: Root only
This extrinsic allows the current owner of an XP key to transfer ownership to another account. The call will fail if the destination account is already the owner or if the caller does not own the XP key.
On success, ownership of the XP key is transferred to the target account and an event is emitted.
Emits Event::XpOwner with the XP key and new owner.
force_genesis_config
Force-update a selected genesis configuration parameter.
Origin: Root only.
This extrinsic allows privileged modification of runtime parameters that were originally defined at genesis.
The parameter to update is specified via the ForceGenesisConfig enum:
MinPulse- Updates the minimum pulse required for reputation effects.InitXp- Updates the initial XP assigned to newly created XP entries.PulseFactor- Updates the pulse stepping configuration (thresholdandper_count).MinTimeStamp- Updated the minimum blocks required for an XP entry to be considered alive.
For PulseFactor, the call fails with Error::LowPulseThreshold
if per_count > threshold, as this would invalidate the stepping logic.
This call directly overwrites storage and emits an event containing the updated configuration variant.
Fields
field: ForceGenesisConfig<T, I>Implementations
Sourceimpl<T: Config<I>, I: 'static> Call<T, I>
impl<T: Config<I>, I: 'static> Call<T, I>
Sourcepub fn new_call_variant_call(
xp_id: XpId<T>,
call: Box<<T as Config<I>>::RuntimeCall>,
) -> Self
pub fn new_call_variant_call( xp_id: XpId<T>, call: Box<<T as Config<I>>::RuntimeCall>, ) -> Self
Create a call with the variant call.
Sourcepub fn new_call_variant_handover(
xp_id: XpId<T>,
new_owner: T::AccountId,
) -> Self
pub fn new_call_variant_handover( xp_id: XpId<T>, new_owner: T::AccountId, ) -> Self
Create a call with the variant handover.
Sourcepub fn new_call_variant_dispose(owner: T::AccountId, xp_id: XpId<T>) -> Self
pub fn new_call_variant_dispose(owner: T::AccountId, xp_id: XpId<T>) -> Self
Create a call with the variant dispose.
Sourcepub fn new_call_variant_force_handover(
owner: T::AccountId,
xp_id: XpId<T>,
new_owner: T::AccountId,
) -> Self
pub fn new_call_variant_force_handover( owner: T::AccountId, xp_id: XpId<T>, new_owner: T::AccountId, ) -> Self
Create a call with the variant force_handover.
Sourcepub fn new_call_variant_force_genesis_config(
field: ForceGenesisConfig<T, I>,
) -> Self
pub fn new_call_variant_force_genesis_config( field: ForceGenesisConfig<T, I>, ) -> Self
Create a call with the variant force_genesis_config.