pub type ReservedXpOf<T: Config<I>, I: 'static = ()> = StorageMap<_GeneratedPrefixForStorageReservedXpOf<T, I>, Blake2_128Concat, XpId<T>, BoundedVec<IdXp<T::ReserveReason, T::Xp>, VariantCountOf<T::ReserveReason>>, OptionQuery>;Expand description
Per-key reserves.
Maps each XP key XpId to a bounded vector of reserve entries IdXp,
with the number of reserves limited by the number of enum variants in
Config::ReserveReason.
Each reserve entry per-key represents XP reserved for a specific reason or runtime intent.
Storage type is [StorageMap] with key type XpId < T > and value type BoundedVec < IdXp < T :: ReserveReason, T :: Xp > , VariantCountOf < T :: ReserveReason > >.
Aliased Type
pub struct ReservedXpOf<T: Config<I>, I: 'static = ()>(/* private fields */);